<?php

namespace Litecms\LeadCapturePage\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\LeadCapturePage\Models\LeadCapturePage;

class LeadCapturePagePolicy
{

    /**
     * Determine if the given user can view the lead_capture_page.
     *
     * @param UserPolicy $user
     * @param LeadCapturePage $lead_capture_page
     *
     * @return bool
     */
    public function view(UserPolicy $user, LeadCapturePage $lead_capture_page)
    {
        if ($user->canDo('lead_capture_page.lead_capture_page.view') && $user->isAdmin()) {
            return true;
        }

        return $lead_capture_page->user_id == user_id() && $lead_capture_page->user_type == user_type();
    }

    /**
     * Determine if the given user can create a lead_capture_page.
     *
     * @param UserPolicy $user
     * @param LeadCapturePage $lead_capture_page
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('lead_capture_page.lead_capture_page.create');
    }

    /**
     * Determine if the given user can update the given lead_capture_page.
     *
     * @param UserPolicy $user
     * @param LeadCapturePage $lead_capture_page
     *
     * @return bool
     */
    public function update(UserPolicy $user, LeadCapturePage $lead_capture_page)
    {
        if ($user->canDo('lead_capture_page.lead_capture_page.edit') && $user->isAdmin()) {
            return true;
        }

        return $lead_capture_page->user_id == user_id() && $lead_capture_page->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given lead_capture_page.
     *
     * @param UserPolicy $user
     * @param LeadCapturePage $lead_capture_page
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, LeadCapturePage $lead_capture_page)
    {
        return $lead_capture_page->user_id == user_id() && $lead_capture_page->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given lead_capture_page.
     *
     * @param UserPolicy $user
     * @param LeadCapturePage $lead_capture_page
     *
     * @return bool
     */
    public function verify(UserPolicy $user, LeadCapturePage $lead_capture_page)
    {
        if ($user->canDo('lead_capture_page.lead_capture_page.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given lead_capture_page.
     *
     * @param UserPolicy $user
     * @param LeadCapturePage $lead_capture_page
     *
     * @return bool
     */
    public function approve(UserPolicy $user, LeadCapturePage $lead_capture_page)
    {
        if ($user->canDo('lead_capture_page.lead_capture_page.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
