<?php

namespace Litecms\LeadCapturePage\Providers;

use Illuminate\Support\ServiceProvider;

class LeadCapturePageServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'lead_capture_page');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'lead_capture_page');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.lead_capture_page', function ($app) {
            return $this->app->make('Litecms\LeadCapturePage\LeadCapturePage');
        });

                // Bind LeadCapturePage to repository
        $this->app->bind(
            'Litecms\LeadCapturePage\Interfaces\LeadCapturePageRepositoryInterface',
            \Litecms\LeadCapturePage\Repositories\Eloquent\LeadCapturePageRepository::class
        );

        $this->app->register(\Litecms\LeadCapturePage\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\LeadCapturePage\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.lead_capture_page'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/lead_capture_page.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/lead_capture_page')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/lead_capture_page')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
